@rem ######################################################
@rem # IBM Confidential OCO Source Material
@rem # Licensed Materials - Property of IBM
@rem # 5724-L17 WebSphere Premises Server
@rem # (C) COPYRIGHT International Business Machines Corp., 2007, 2008.
@rem #
@rem # US Government Users Restricted Rights - Use, duplication or
@rem # disclosure restricted by GSA ADP Schedule Contract with IBM
@rem # Corp
@rem #
@rem # The source code for this program is not published or otherwise 
@rem # divested of its trade secrets, irrespective of what has been 
@rem # deposited with the U. S. Copyright Office.
@rem ######################################################

@rem #
@rem # HTTP_INSTALL_DIR: IBM HTTP Server installation directory (C:\Program Files\IBM\HTTPServer)
@rem # MQ_INSTALL_DIR: IBM WebSphere MQ installation directory (C:\Program Files\IBM\WebSphere MQ)
@rem # RAD_INSTALL_DIR: IBM RAD installation directory (C:\Program Files\IBM\SDP70)
@rem # RAD_WORKSPACE_DIR: RAD workspace directory (C:\workspace)
@rem # WAS_PROFILE_NAME: RAD WebSphere profile name (AppSrv01)
@rem # DB_INSTALL_DIR: DB installation directory (DB2: C:\Program Files\IBM\SQLLIB; Oracle: C:\oracle\product\10.2.0\client_1)
@rem # DB_TYPE: database type (db2 or oracle)
@rem # DB_HOSTNAME: database server hostname (localhost)
@rem # DB_PORT_NUMBER: database server port number (DB2: 50000; Oracle: 1521)
@rem # DB_NAME: database name (IBMRFID)
@rem # DB_USERNAME: database user ID
@rem # DB_PASSWORD: database password
@rem #

@set HTTP_INSTALL_DIR=C:\Program Files\IBM\HTTPServer
@set MQ_INSTALL_DIR=C:\Program Files\IBM\WebSphere MQ
@set RAD_INSTALL_DIR=C:\Program Files\IBM\SDP70
@set RAD_WORKSPACE_DIR=C:\workspace
@set WAS_PROFILE_NAME=AppSrv01
@set DB_INSTALL_DIR=C:\Program Files\IBM\SQLLIB
@set DB_TYPE=db2
@set DB_HOSTNAME=localhost
@set DB_PORT_NUMBER=50000
@set DB_NAME=IBMRFID
@set DB_USERNAME=db2admin
@set DB_PASSWORD=db2admin

@rem #
@rem # Optional
@rem #
@rem # DMS_BUNDLES_DIR: DMS bundles directory (%HTTP_INSTALL_DIR%\htdocs\en_US)
@rem #

@set DMS_BUNDLES_DIR=%HTTP_INSTALL_DIR%\htdocs\en_US

@rem #
@rem # Do not change anything below this comment
@rem #

@rem # WAS_INSTALL_DIR: WebSphere Application Server installation directory (%RAD_INSTALL_DIR%\runtimes\base_v61)
@rem # IBM_RFID_HOME: WebSphere RFID Premises Server installation directory (%RAD_WORKSPACE_DIR%\IBM\RFID)
@rem # OS_TYPE: Operating system type (only Windows is currently supported)
@rem # INSTALL_TYPE: Installation type (only TOOLKIT is currently supported)

@set WAS_INSTALL_DIR=%RAD_INSTALL_DIR%\runtimes\base_v61
@set IBM_RFID_HOME=%RAD_WORKSPACE_DIR%\IBM\RFID
@set OS_TYPE=Windows
@set INSTALL_TYPE=TOOLKIT

@pushd .

@set INSTALL_LOG="%IBM_RFID_HOME%\logs\install.log"
@echo Logging messages to %INSTALL_LOG%.

@set TEMP_WAS_PROFILE_NAME=%WAS_PROFILE_NAME%
@echo Setup command line.
@call "%WAS_INSTALL_DIR%\bin\setupCmdLine.bat" >> %INSTALL_LOG%
@set WAS_PROFILE_NAME=%TEMP_WAS_PROFILE_NAME%

@set TEMP_PATH=%PATH%
@set PATH=%WAS_PATH%
@echo Updating Premises Server install files.
@java "-DOS_TYPE=%OS_TYPE%" "-DINSTALL_TYPE=%INSTALL_TYPE%" "-DWAS_INSTALL_DIR=%WAS_INSTALL_DIR%" "-DWAS_PROFILE_NAME=%WAS_PROFILE_NAME%" "-DMQ_INSTALL_DIR=%MQ_INSTALL_DIR%" "-DIBM_RFID_HOME=%IBM_RFID_HOME%" "-DDMS_BUNDLES_DIR=%DMS_BUNDLES_DIR%" "-DDB_TYPE=%DB_TYPE%" "-DDB_INSTALL_DIR=%DB_INSTALL_DIR%" "-DDB_HOSTNAME=%DB_HOSTNAME%" "-DDB_PORT_NUMBER=%DB_PORT_NUMBER%" "-DDB_NAME=%DB_NAME%" "-DDB_USERNAME=%DB_USERNAME%" "-DDB_PASSWORD=%DB_PASSWORD%" -jar ibmrfid_premises_config.jar >> %INSTALL_LOG%
@set PATH=%TEMP_PATH%

@if %ERRORLEVEL% NEQ 0 GOTO ERROR

@rem start WAS profile
@echo Starting WAS server profile.
@echo Starting WAS server profile. >> %INSTALL_LOG%
@call "%WAS_INSTALL_DIR%\bin\startServer.bat" server1 -profileName "%WAS_PROFILE_NAME%" >> %INSTALL_LOG%

@cd /d "%IBM_RFID_HOME%\premises"
@call install.bat

@cd /d "%IBM_RFID_HOME%\..\DMS\install\bundlesmgmt"
@call bm_install.bat

@rem # copy bundles
@echo Copying DTS bundles.
@echo Copying DTS bundles. >> %INSTALL_LOG%
@xcopy "%IBM_RFID_HOME%\bundles\*" "%DMS_BUNDLES_DIR%\bundles" /E /I /Y >> %INSTALL_LOG%

@rem restart MQ
@echo Restarting WebSphere MQ.
@echo Restarting WebSphere MQ. >> %INSTALL_LOG%
@net stop "IBM MQSeries" >> %INSTALL_LOG%
@net start "IBM MQSeries" >> %INSTALL_LOG%

@rem stop WAS profile
@echo Stopping WAS server profile.
@echo Stopping WAS server profile. >> %INSTALL_LOG%
@call "%WAS_INSTALL_DIR%\bin\stopServer.bat" server1 -profileName "%WAS_PROFILE_NAME%" >> %INSTALL_LOG%

@popd

:SUCCESS
@echo.
@echo Premises Server configuration complete.
@echo.
@goto END

:ERROR
@echo.
@echo An error has occurred.  Unable to continue.  See %INSTALL_LOG% for details.
@echo.

:END
